==> sca-patterns-sle12-1.5.5.tar.gz: sca-patterns-sle12-1.5.5/patterns/SLE/sle12sp4/openssl-1_0_0_SUSE-SU-2023_2624-1_sles_12.4.py <==
#!/usr/bin/python3
#
# Title:       Moderate Security Announcement for openssl-1_0_0 SUSE-SU-2023:2624-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP4
# URL:         https://lists.suse.com/pipermail/sle-security-updates/2023-June/015284.html
# Source:      Security Announcement Generator (sagen.py) v2.0.13
# Modified:    2023 Aug 31
#
##############################################################################
# Copyright (C) 2023 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

meta_class = "Security"
meta_category = "SLE"
meta_component = "openssl-1_0_0"
pattern_filename = os.path.basename(__file__)
primary_link = "META_LINK_Security"
overall = Core.TEMP
overall_info = "NOT SET"
other_links = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2023-June/015284.html"
Core.init(meta_class, meta_category, meta_component, pattern_filename, primary_link, overall, overall_info, other_links)

def main():
	ltss = False
	name = 'openssl-1_0_0'
	main = ''
	severity = 'Moderate'
	tag = 'SUSE-SU-2023:2624-1'
	packages = {}
	server = SUSE.getHostInfo()

	if ( server['DistroVersion'] == 12):
		if ( server['DistroPatchLevel'] == 4 ):
			packages = {
				'libopenssl-1_0_0-devel': '1.0.2p-3.78.1',
				'libopenssl1_0_0': '1.0.2p-3.78.1',
				'libopenssl1_0_0-debuginfo': '1.0.2p-3.78.1',
				'libopenssl1_0_0-hmac': '1.0.2p-3.78.1',
				'openssl-1_0_0': '1.0.2p-3.78.1',
				'openssl-1_0_0-debuginfo': '1.0.2p-3.78.1',
				'openssl-1_0_0-debugsource': '1.0.2p-3.78.1',
			}
			SUSE.securityAnnouncementPackageCheck(name, main, ltss, severity, tag, packages)
		else:
			Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the service pack scope")
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the distribution scope")

	Core.printPatternResults()

if __name__ == "__main__":
	main()

==> sca-patterns-sle12-1.5.7.tar.gz: sca-patterns-sle12-1.5.7/patterns/SLE/sle12sp4/openssl-1_1_SUSE-SU-2023_2328-1_sles_12.4.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for openssl-1_1 SUSE-SU-2023:2328-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP4
# URL:         https://lists.suse.com/pipermail/sle-security-updates/2023-May/015010.html
# Source:      Security Announcement Generator (sagen.py) v2.0.6
# Modified:    2023 Jun 13
#
##############################################################################
# Copyright (C) 2023 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

meta_class = "Security"
meta_category = "SLE"
meta_component = "openssl-1_1"
pattern_filename = os.path.basename(__file__)
primary_link = "META_LINK_Security"
overall = Core.TEMP
overall_info = "NOT SET"
other_links = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2023-May/015010.html"
Core.init(meta_class, meta_category, meta_component, pattern_filename, primary_link, overall, overall_info, other_links)

def main():
	ltss = False
	name = 'openssl-1_1'
	main = ''
	severity = 'Important'
	tag = 'SUSE-SU-2023:2328-1'
	packages = {}
	server = SUSE.getHostInfo()

	if ( server['DistroVersion'] == 12):
		if ( server['DistroPatchLevel'] == 4 ):
			packages = {
				'libopenssl1_1': '1.1.1d-2.84.1',
				'libopenssl1_1-debuginfo': '1.1.1d-2.84.1',
				'libopenssl1_1-hmac': '1.1.1d-2.84.1',
				'openssl-1_1': '1.1.1d-2.84.1',
				'openssl-1_1-debuginfo': '1.1.1d-2.84.1',
				'openssl-1_1-debugsource': '1.1.1d-2.84.1',
			}
			SUSE.securityAnnouncementPackageCheck(name, main, ltss, severity, tag, packages)
		else:
			Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the service pack scope")
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the distribution scope")

	Core.printPatternResults()

if __name__ == "__main__":
	main()
